@@ -19,14 +19,13 @@
 template <class T>
 class AutoQPointer : public QPointer<T>
 {
-    public:
-        AutoQPointer() : QPointer<T>() {}
-        AutoQPointer(T* p) : QPointer<T>(p) {}
-        AutoQPointer(const QPointer<T>& p) : QPointer<T>(p) {}
-        ~AutoQPointer()  { delete this->data(); }
-        AutoQPointer<T>& operator=(const AutoQPointer<T>& p) { QPointer<T>::operator=(p); return *this; }
-        AutoQPointer<T>& operator=(T* p) { QPointer<T>::operator=(p); return *this; }
+public:
+    AutoQPointer() = default;
+    AutoQPointer(T* p) : QPointer<T>(p) {}    //cppcheck-suppress noExplicitConstructor
+    AutoQPointer(const QPointer<T>& p) : QPointer<T>(p) {}
+    ~AutoQPointer()  { delete this->data(); }
+    AutoQPointer<T>& operator=(const AutoQPointer<T>& p) { QPointer<T>::operator=(p); return *this; }
+    AutoQPointer<T>& operator=(T* p) { QPointer<T>::operator=(p); return *this; }
 };
 
-
 // vim: et sw=4:
